#
# spec file for package python-jupyter-sphinx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python39 1
Name:           python-jupyter-sphinx
Version:        0.5.3
Release:        2.2
Summary:        Jupyter Sphinx Extensions
License:        BSD-3-Clause
URL:            https://github.com/jupyter-widgets/jupyter-sphinx
Source:         https://github.com/jupyter/jupyter-sphinx/archive/v%{version}.tar.gz#/jupyter-sphinx-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-IPython
Requires:       python-Sphinx >= 7
Requires:       python-ipykernel >= 4.5.1
Requires:       python-ipywidgets >= 7.0.0
Requires:       python-nbconvert >= 5.5
Requires:       python-nbformat
Provides:       python-jupyter_sphinx = %{version}
Obsoletes:      python-jupyter_sphinx < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module IPython}
BuildRequires:  %{python_module Sphinx >= 7}
BuildRequires:  %{python_module Sphinx-latex}
BuildRequires:  %{python_module ipykernel >= 4.5.1}
BuildRequires:  %{python_module ipywidgets >= 7.0.0}
BuildRequires:  %{python_module nbconvert >= 5.5}
BuildRequires:  %{python_module nbformat}
BuildRequires:  %{python_module pytest}
# /SECTION
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-jupyter-sphinx = %{version}
%endif
%python_subpackages

%description
Jupyter Sphinx extensions enable jupyter-specific features in sphinx.

%prep
%autosetup -p1 -n jupyter-sphinx-%{version}
sed -i 's/"--color=yes", //' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export JUPYTER_PLATFORM_DIRS=1
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/jupyter_sphinx-%{version}.dist-info
%{python_sitelib}/jupyter_sphinx/

%changelog
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.5.3, 0.5.2, 0.5.1
  * releaser changes
- Release 0.5.0
  * drop support for Python 3.6 by @12rambau in #229
  * Add direct dependency on ipykernel by @garrison in #226
  * Adapt to level config to match other Jupyter repos by
    @blink1073 in #237
- Drop jupyter-sphinx-pr226-ipykernel.patch
- Drop jupyter-sphinx-pr233-pathlib.patch
* Thu Sep 14 2023 Ben Greiner <code@bnavigator.de>
- Add jupyter-sphinx-pr233-pathlib.patch
  gh#jupyter/jupyter-sphinx#233
* Wed Aug 23 2023 Ben Greiner <code@bnavigator.de>
- Add ipykernel to requirements
  * jupyter-sphinx-pr226-ipykernel.patch
  * gh#jupyter/jupyter-sphinx#226
- PEP517
* Wed Jul 13 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * require Sphinx-latex for tests
- update to version 0.4.0:
  * Allow adding inputs and outputs that are not executed using
    jupyter-input and jupyter-output directives.
  * Improve script handling by using nbconvert directly.
  * Remove deprecated enabling of the extension as
    jupyter_sphinx.execute.
  * Implement different output priorities in HTML and LaTeX
    builders. In practice this allows to provide a better fallback in
    PDF output.
  * Introduce new jupyter-download syntax compatible with Sphinx≥4,
    jupyter-download-nb, jupyter-download-notebook, and
    jupyter-download-script
  * Do not overwrite CSS and JS if files already exist in _static/,
    this allows to customize the CSS and JS file.
* Thu Jul  1 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.3.2
  * Switch the extension name to jupyter-sphinx, deprecate
    jupyter-sphinx.execute.
  * Miscellaneous bugfixes following the restructuring of the
    codebase.
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.4:
  * Documentation updates
  * Test fixes
* Fri Jan  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.2.3
  * strip Latex math delimiters that would be rendered by math blocks
  * adjusts jupyter_container margin as a better fix
  * fix sphinx_rtd_theme spacing issue
  * Update jupyter-sphinx.css
  * fix for overflow errror in code cell
- Drop python2 support due to dependencies dropping python2
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.2
  * Added jupyter_sphinx_linenos and jupyter_sphinx_continue_linenos conf…
  * Update jupyter_sphinx/execute.py
  * Use math_block node directly instead of deprecated displaymath
  * added classes to stderr output
  * added continue_linenos directive, doc updates, and tests
  * added css insertion to improve display
  * added css/ to package_data
  * added linenos flag, updated docs, and basic tests
  * added padding around stderr
  * added tests
  * css-related code updates and doc additions
  * make output to stderr print a warning, rather than raise an exception
  * move sequential cells up on y-axis
  * moved css copying to build_finished and addition to builder_initiated
  * turn off erroneous output highlighting
  * use the default "contents.rst" as the index document
- Rename to python-jupyter-sphinx to match upstream rename.
* Sun Jul 28 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.1
  * make ThebelabSourceCell into a container with original code inside
  * include thebelab javascript and css in source distributions
- Update to 0.2.0
  * reorder code to remove superfluous output
  * specify a fallback when the metadata lacks pygments lexer
  * Simplify ThebeSourceNode constructor
  * Replace f-strings for compatibility
  * Restructure nodes in setup
  * Fix hide code for non html builders
  * fix compatibility with latex builder
  * Add thebelab support
  * remove widget views for non-html builds
  * add javascript support
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Fix dependencies.
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to version 1.4
  * Cleanup execute
* Fri Aug  3 2018 toddrme2178@gmail.com
- Update to version 1.3
  * Pep8 compliancy
  * Overwrite IPython display earlier in the sphinx build
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
